# helicsOCT

## Prerequisites

- Octave must be installed on your system

## BUILD HELICS with the Octave interface

In CMake turn on the BUILD_OCTAVE_INTERFACE option

a file helics.oct will be created and placed in <install>/octave directory along with the needed libraries
